# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetNotificationsResult:
    """
    A collection of values returned by getNotifications.
    """
    def __init__(__self__, id=None, ids=None, notifications=None, output_file=None, scaling_group_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        __self__.ids = ids
        """
        A list of notification ids.
        """
        if notifications and not isinstance(notifications, list):
            raise TypeError("Expected argument 'notifications' to be a list")
        __self__.notifications = notifications
        """
        A list of notifications. Each element contains the following attributes:
        """
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
        if scaling_group_id and not isinstance(scaling_group_id, str):
            raise TypeError("Expected argument 'scaling_group_id' to be a str")
        __self__.scaling_group_id = scaling_group_id
        """
        ID of the scaling group.
        """
class AwaitableGetNotificationsResult(GetNotificationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNotificationsResult(
            id=self.id,
            ids=self.ids,
            notifications=self.notifications,
            output_file=self.output_file,
            scaling_group_id=self.scaling_group_id)

def get_notifications(ids=None,output_file=None,scaling_group_id=None,opts=None):
    """
    This data source provides available notification resources. 

    > **NOTE:** Available in 1.72.0+

    > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/d/ess_notifications.html.markdown.


    :param list ids: A list of notification ids.
    :param str scaling_group_id: Scaling group id the notifications belong to.
    """
    __args__ = dict()


    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['scalingGroupId'] = scaling_group_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:ess/getNotifications:getNotifications', __args__, opts=opts).value

    return AwaitableGetNotificationsResult(
        id=__ret__.get('id'),
        ids=__ret__.get('ids'),
        notifications=__ret__.get('notifications'),
        output_file=__ret__.get('outputFile'),
        scaling_group_id=__ret__.get('scalingGroupId'))
