# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetBandwidthLimitsResult:
    """
    A collection of values returned by getBandwidthLimits.
    """
    def __init__(__self__, id=None, instance_ids=None, limits=None, output_file=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
        if instance_ids and not isinstance(instance_ids, list):
            raise TypeError("Expected argument 'instance_ids' to be a list")
        __self__.instance_ids = instance_ids
        if limits and not isinstance(limits, list):
            raise TypeError("Expected argument 'limits' to be a list")
        __self__.limits = limits
        """
        A list of CEN Bandwidth Limits. Each element contains the following attributes:
        """
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        __self__.output_file = output_file
class AwaitableGetBandwidthLimitsResult(GetBandwidthLimitsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBandwidthLimitsResult(
            id=self.id,
            instance_ids=self.instance_ids,
            limits=self.limits,
            output_file=self.output_file)

def get_bandwidth_limits(instance_ids=None,output_file=None,opts=None):
    """
    This data source provides CEN Bandwidth Limits available to the user.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-alicloud/blob/master/website/docs/d/cen_bandwidth_limits.html.markdown.


    :param list instance_ids: A list of CEN instances IDs.
    """
    __args__ = dict()


    __args__['instanceIds'] = instance_ids
    __args__['outputFile'] = output_file
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getBandwidthLimits:getBandwidthLimits', __args__, opts=opts).value

    return AwaitableGetBandwidthLimitsResult(
        id=__ret__.get('id'),
        instance_ids=__ret__.get('instanceIds'),
        limits=__ret__.get('limits'),
        output_file=__ret__.get('outputFile'))
